@@ -49,12 +49,12 @@ class Packager(_PackagerMarkdown, _PackagerGitHub, _PackagerFiles, _PackagerMeta
 
     def setup_all(self):
         """ Called by GitHub Actions when a commit is pushed. """
-        # self.generate_git_exclude()
-        # self.generate_readme()
-        # self.generate_setup()
-        # self.generate_license()
-        # self.localrepo.commit_and_push()
-        # self.sync_github_metadata()
+        self.generate_git_exclude()
+        self.generate_readme()
+        self.generate_setup()
+        self.generate_license()
+        self.localrepo.commit_and_push()
+        self.sync_github_metadata()
         self.upload()
 
 
